# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkSpatialObjectPropertyPython
else:
    import _itkSpatialObjectPropertyPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkRGBAPixelPython
class itkSpatialObjectProperty(object):
    r"""Proxy of C++ itkSpatialObjectProperty class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _itkSpatialObjectPropertyPython.delete_itkSpatialObjectProperty

    def Clear(self):
        r"""Clear(self)"""
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_Clear(self)

    def GetColor(self, *args):
        r"""
        GetColor(self) -> itkRGBAPixelD
        GetColor(self) -> itkRGBAPixelD
        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetColor(self, *args)

    def SetColor(self, *args):
        r"""
        SetColor(self, color)

        Parameters
        ----------
        color: itkRGBAPixelD const &

        SetColor(self, r, g, b)

        Parameters
        ----------
        r: double
        g: double
        b: double

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetColor(self, *args)

    def SetRed(self, r):
        r"""
        SetRed(self, r)

        Parameters
        ----------
        r: double

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetRed(self, r)

    def GetRed(self):
        r"""GetRed(self) -> double"""
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetRed(self)

    def SetGreen(self, g):
        r"""
        SetGreen(self, g)

        Parameters
        ----------
        g: double

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetGreen(self, g)

    def GetGreen(self):
        r"""GetGreen(self) -> double"""
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetGreen(self)

    def SetBlue(self, b):
        r"""
        SetBlue(self, b)

        Parameters
        ----------
        b: double

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetBlue(self, b)

    def GetBlue(self):
        r"""GetBlue(self) -> double"""
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetBlue(self)

    def SetAlpha(self, a):
        r"""
        SetAlpha(self, a)

        Parameters
        ----------
        a: double

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetAlpha(self, a)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetAlpha(self)

    def SetName(self, name):
        r"""
        SetName(self, name)

        Parameters
        ----------
        name: std::string const &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetName(self, name)

    def GetName(self):
        r"""GetName(self) -> std::string const &"""
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetName(self)

    def SetTagScalarValue(self, tag, value):
        r"""
        SetTagScalarValue(self, tag, value)

        Parameters
        ----------
        tag: std::string const &
        value: double

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetTagScalarValue(self, tag, value)

    def SetTagStringValue(self, tag, value):
        r"""
        SetTagStringValue(self, tag, value)

        Parameters
        ----------
        tag: std::string const &
        value: std::string const &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetTagStringValue(self, tag, value)

    def GetTagScalarValue(self, *args):
        r"""
        GetTagScalarValue(self, tag, value) -> bool

        Parameters
        ----------
        tag: std::string const &
        value: double &

        GetTagScalarValue(self, tag) -> double

        Parameters
        ----------
        tag: std::string const &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetTagScalarValue(self, *args)

    def GetTagStringValue(self, tag):
        r"""
        GetTagStringValue(self, tag) -> std::string

        Parameters
        ----------
        tag: std::string const &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetTagStringValue(self, tag)

    def GetTagScalarDictionary(self, *args):
        r"""
        GetTagScalarDictionary(self) -> std::map< std::string,double,std::less< std::string >,std::allocator< std::pair< std::string const,double > > >
        GetTagScalarDictionary(self) -> std::map< std::string,double,std::less< std::string >,std::allocator< std::pair< std::string const,double > > > const &
        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetTagScalarDictionary(self, *args)

    def GetTagStringDictionary(self, *args):
        r"""
        GetTagStringDictionary(self) -> std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >
        GetTagStringDictionary(self) -> std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > > const &
        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_GetTagStringDictionary(self, *args)

    def SetTagScalarDictionary(self, dict):
        r"""
        SetTagScalarDictionary(self, dict)

        Parameters
        ----------
        dict: std::map< std::string,double,std::less< std::string >,std::allocator< std::pair< std::string const,double > > > const &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetTagScalarDictionary(self, dict)

    def SetTagStringDictionary(self, dict):
        r"""
        SetTagStringDictionary(self, dict)

        Parameters
        ----------
        dict: std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > > const &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_SetTagStringDictionary(self, dict)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_Print(self, os)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkSpatialObjectProperty
        __init__(self, arg0) -> itkSpatialObjectProperty

        Parameters
        ----------
        arg0: itkSpatialObjectProperty const &

        """
        _itkSpatialObjectPropertyPython.itkSpatialObjectProperty_swiginit(self, _itkSpatialObjectPropertyPython.new_itkSpatialObjectProperty(*args))

# Register itkSpatialObjectProperty in _itkSpatialObjectPropertyPython:
_itkSpatialObjectPropertyPython.itkSpatialObjectProperty_swigregister(itkSpatialObjectProperty)

